@@ -23,6 +23,8 @@
 
 #include "aqhbci/banking/user.h"
 #include "aqhbci/banking/provider.h"
+#include "aqhbci/banking/provider_online.h"
+#include "aqhbci/banking/provider_iniletter.h"
 #include "dlg_rdh_special_l.h"
 
 #include <gwenhywfar/gwenhywfar.h>
@@ -1516,6 +1518,8 @@ int GWENHYWFAR_CB AH_NewKeyFileDialog_SignalHandler(GWEN_DIALOG *dlg,
   case GWEN_DialogEvent_TypeLast:
     return GWEN_DialogEvent_ResultNotHandled;
 
+  default:
+    break;
   }
 
   return GWEN_DialogEvent_ResultNotHandled;
