@@ -728,6 +728,14 @@ void AH_Job_SetStatus(AH_JOB *j, AH_JOB_STATUS st)
 
 
 
+void AH_Job_SetJobStatusOnMatch(AH_JOB *j, AH_JOB_STATUS matchSt, AH_JOB_STATUS newSt)
+{
+  if (matchSt==AH_JobStatusAll || j->status==matchSt)
+    AH_Job_SetStatus(j, newSt);
+}
+
+
+
 void AH_Job_AddSigner(AH_JOB *j, const char *s)
 {
   GWEN_BUFFER *lbuf;
@@ -1293,6 +1301,7 @@ int AH_Job_HasResultWithCode(const AH_JOB *j, int wantedCode)
 
 
 
+
 AH_JOB *AH_Job__freeAll_cb(AH_JOB *j, void *userData)
 {
   assert(j);
@@ -1426,16 +1435,13 @@ void AH_Job_SetUsedTan(AH_JOB *j, const char *s)
 
 void AH_Job_Log(AH_JOB *j, GWEN_LOGGER_LEVEL ll, const char *txt)
 {
-  char buffer[32];
   GWEN_TIME *ti;
   GWEN_BUFFER *lbuf;
 
   assert(j);
 
   lbuf=GWEN_Buffer_new(0, 128, 0, 1);
-  snprintf(buffer, sizeof(buffer), "%02d", ll);
-  GWEN_Buffer_AppendString(lbuf, buffer);
-  GWEN_Buffer_AppendByte(lbuf, ':');
+  GWEN_Buffer_AppendArgs(lbuf, "%02d:", ll);
   ti=GWEN_CurrentTime();
   assert(ti);
   GWEN_Time_toString(ti, "YYYYMMDD:hhmmss:", lbuf);
@@ -1443,9 +1449,7 @@ void AH_Job_Log(AH_JOB *j, GWEN_LOGGER_LEVEL ll, const char *txt)
   GWEN_Text_EscapeToBufferTolerant(AH_PROVIDER_NAME, lbuf);
   GWEN_Buffer_AppendByte(lbuf, ':');
   GWEN_Text_EscapeToBufferTolerant(txt, lbuf);
-  GWEN_StringList_AppendString(j->log,
-                               GWEN_Buffer_GetStart(lbuf),
-                               0, 0);
+  GWEN_StringList_AppendString(j->log, GWEN_Buffer_GetStart(lbuf), 0, 0);
   GWEN_Buffer_free(lbuf);
 }
 
