@@ -980,7 +980,9 @@ int createAndAddRequest(AB_BANKING *ab,
                         AB_TRANSACTION_COMMAND cmd,
                         const GWEN_DATE *fromDate,
                         const GWEN_DATE *toDate,
-                        int ignoreUnsupported)
+                        int ignoreUnsupported,
+                        AB_TRANSACTION_ACK ackMethod,
+                        uint32_t number)
 {
   uint32_t aid;
   AB_TRANSACTION *j;
@@ -996,6 +998,13 @@ int createAndAddRequest(AB_BANKING *ab,
       if (toDate)
         AB_Transaction_SetLastDate(j, toDate);
     }
+    else if (cmd==AB_Transaction_CommandGetEStatements) {
+      if (fromDate)
+        AB_Transaction_SetFirstDate(j, fromDate);
+      if (number>0)
+        AB_Transaction_SetEstatementNumber(j, number);
+    }
+    AB_Transaction_SetAcknowledge(j, ackMethod);
     AB_Transaction_List2_PushBack(tList, j);
     return 0;
   }
@@ -1027,42 +1036,53 @@ int createAndAddRequests(AB_BANKING *ab,
                          AB_ACCOUNT_SPEC *as,
                          const GWEN_DATE *fromDate,
                          const GWEN_DATE *toDate,
-                         uint32_t requestFlags)
+                         uint32_t requestFlags,
+                         uint32_t number)
 {
   int ignoreUnsupported=requestFlags & AQBANKING_TOOL_REQUEST_IGNORE_UNSUP;
+  int ackMethod=AB_Transaction_AckNever;
   int rv;
 
   assert(ab);
   assert(tList);
   assert(as);
 
+  if (requestFlags & AQBANKING_TOOL_REQUEST_ACKNOWLEDGE) {
+    ackMethod=AB_Transaction_AckJobsWithAckCode;
+  }
+
   /* create and add requests */
   if (requestFlags & AQBANKING_TOOL_REQUEST_BALANCE) {
-    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandGetBalance, fromDate, toDate, ignoreUnsupported);
+    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandGetBalance, fromDate, toDate, ignoreUnsupported, ackMethod,
+                           number);
     if (rv)
       return rv;
   }
 
   if (requestFlags & AQBANKING_TOOL_REQUEST_STATEMENTS) {
-    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandGetTransactions, fromDate, toDate, ignoreUnsupported);
+    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandGetTransactions, fromDate, toDate, ignoreUnsupported,
+                           ackMethod, number);
     if (rv)
       return rv;
   }
 
   if (requestFlags & AQBANKING_TOOL_REQUEST_SEPASTO) {
-    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandSepaGetStandingOrders, fromDate, toDate, ignoreUnsupported);
+    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandSepaGetStandingOrders, fromDate, toDate, ignoreUnsupported,
+                           ackMethod, number);
     if (rv)
       return rv;
   }
 
   if (requestFlags & AQBANKING_TOOL_REQUEST_ESTATEMENTS) {
-    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandGetEStatements, fromDate, toDate, ignoreUnsupported);
+    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandGetEStatements, fromDate, toDate, ignoreUnsupported,
+                           ackMethod, number);
     if (rv)
       return rv;
   }
 
   if (requestFlags & AQBANKING_TOOL_REQUEST_DEPOT) {
-    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandGetDepot, fromDate, toDate, ignoreUnsupported);
+    rv=createAndAddRequest(ab, tList, as, AB_Transaction_CommandGetDepot, fromDate, toDate, ignoreUnsupported, ackMethod,
+                           number);
     if (rv)
       return rv;
   }
